@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
 File: edge_bool_t_rt.h
 
+Copyright (c) 2017 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2017 Celia Virginia Vergara Castillo
 Mail: vicky_vergara@hotmail.com
 
@@ -35,12 +38,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #   include <stdint.h>
 #endif
 
-struct Edge_bool_t_rt {
+struct Edge_bool_t {
   int64_t id;
   int64_t source;
   int64_t target;
   bool going;
-  bool coming;
+};
+
+/* TODO on v4, only the edge_id is returned
+ * source and target are kept for backward compatability */
+struct Only_int_rt {
+  int64_t source;
+  int64_t target;
   int64_t edge_id;
 };
 
