@@ -33,21 +33,20 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #ifdef __cplusplus
 #   include <cstdint>
 typedef int64_t int64;
-typedef double float8;
 #else
 #   include <stdint.h>
 #endif
 
 struct restrict_t {
     int target_id;
-    float8 to_cost;
+    double to_cost;
     int via[MAX_RULE_LENGTH];
 };
 
 struct path_element_tt {
-    int64 vertex_id;
-    int64 edge_id;
-    float8 cost;
+    int64_t vertex_id;
+    int64_t edge_id;
+    double cost;
 };
 
 
