@@ -31,7 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define INCLUDE_CPP_COMMON_PATH_T_HPP_
 #pragma once
 
-#include <stdint.h>
+#include <cstdint>
 
 struct Path_t {
     int64_t node;
