@@ -42,7 +42,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include "cpp_common/basePath_SSEC.hpp"
 #include "cpp_common/pgr_base_graph.hpp"
-#include "cpp_common/interruption.h"
+#include "cpp_common/interruption.hpp"
 
 template < class G > class Pgr_randomSpanningTree;
 // user's functions
