@@ -1,6 +1,5 @@
 /*PGR-GNU*****************************************************************
-
-FILE: dnode.cpp
+File: dnode.cpp
 
 Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
@@ -23,9 +22,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
 
-#include "vrp/dnode.h"
+#include "vrp/dnode.hpp"
 
-#include "vrp/pgr_pickDeliver.h"
+#include "vrp/pickDeliver.hpp"
 
 namespace pgrouting {
 namespace vrp {
