@@ -134,8 +134,8 @@ get_route(
 
 void
 pgr_do_trspVia(
-        char *edges_sql,
-        char *restrictions_sql,
+        const char *edges_sql,
+        const char *restrictions_sql,
         ArrayType* viaArr,
 
         bool directed,
@@ -155,7 +155,7 @@ pgr_do_trspVia(
     std::ostringstream log;
     std::ostringstream err;
     std::ostringstream notice;
-    char *hint = nullptr;
+    const char *hint = nullptr;
 
     try {
         pgassert(!(*log_msg));
