@@ -32,7 +32,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "c_common/debug_macro.h"
 #include "c_common/e_report.h"
 #include "c_common/time_msg.h"
-#include "c_common/pgdata_getters.h"
 #include "drivers/withPoints/get_new_queries.h"
 #include "drivers/withPoints/withPointsVia_driver.h"
 
@@ -44,7 +43,7 @@ void
 process(
         char* edges_sql,
         char* points_sql,
-        ArrayType *viasArr,
+        ArrayType *vias,
         bool directed,
         bool strict,
         bool U_turn_on_edge,
@@ -59,55 +58,16 @@ process(
 
     driving_side[0] = estimate_drivingSide(driving_side[0]);
 
-    /*
-     * Processing Via
-     */
-    size_t size_vias = 0;
-    int64_t* vias = pgr_get_bigIntArray(&size_vias, viasArr, false, &err_msg);
-    throw_error(err_msg, "While getting via vertices");
-
-    // TODO(vicky) figure out what happens when one point or 0 points are given
-
-    /*
-     * Processing Points
-     */
-    Point_on_edge_t *points = NULL;
-    size_t total_points = 0;
-    pgr_get_points(points_sql, &points, &total_points, &err_msg);
-    throw_error(err_msg, points_sql);
-
     char *edges_of_points_query = NULL;
     char *edges_no_points_query = NULL;
     get_new_queries(edges_sql, points_sql, &edges_of_points_query, &edges_no_points_query);
 
-    Edge_t *edges_of_points = NULL;
-    size_t total_edges_of_points = 0;
-
-    Edge_t *edges = NULL;
-    size_t total_edges = 0;
-
-    pgr_get_edges(edges_no_points_query, &edges, &total_edges, true, false, &err_msg);
-    throw_error(err_msg, edges_no_points_query);
-    pgr_get_edges(edges_of_points_query, &edges_of_points, &total_edges_of_points, true, false, &err_msg);
-    throw_error(err_msg, edges_of_points_query);
-
-    {pfree(edges_of_points_query); edges_of_points_query = NULL;}
-    {pfree(edges_no_points_query); edges_no_points_query = NULL;}
-
-    if ((total_edges + total_edges_of_points) == 0) {
-        if (edges) {pfree(edges), edges = NULL;}
-        if (edges_of_points) {pfree(edges_of_points), edges_of_points = NULL;}
-        if (vias) {pfree(vias), vias = NULL;}
-        pgr_SPI_finish();
-        return;
-    }
-
     clock_t start_t = clock();
-    do_withPointsVia(
-            edges, total_edges,
-            points, total_points,
-            edges_of_points, total_edges_of_points,
-            vias, size_vias,
+    pgr_do_withPointsVia(
+            edges_no_points_query,
+            points_sql,
+            edges_of_points_query,
+            vias,
 
             directed,
 
@@ -127,15 +87,8 @@ process(
         (*result_count) = 0;
     }
 
-    pgr_global_report(log_msg, notice_msg, err_msg);
+    pgr_global_report(&log_msg, &notice_msg, &err_msg);
 
-    if (points) {pfree(points), points = NULL;}
-    if (edges) {pfree(edges), edges = NULL;}
-    if (edges_of_points) {pfree(edges_of_points), edges_of_points = NULL;}
-    if (vias) {pfree(vias), vias = NULL;}
-    if (log_msg) {pfree(log_msg); log_msg = NULL;}
-    if (notice_msg) {pfree(notice_msg); notice_msg = NULL;}
-    if (err_msg) {pfree(err_msg); err_msg = NULL;}
     pgr_SPI_finish();
 }
 
@@ -145,10 +98,8 @@ _pgr_withpointsvia(PG_FUNCTION_ARGS) {
     FuncCallContext     *funcctx;
     TupleDesc            tuple_desc;
 
-    /**********************************************************************/
     Routes_t  *result_tuples = 0;
     size_t result_count = 0;
-    /**********************************************************************/
 
     if (SRF_IS_FIRSTCALL()) {
         MemoryContext   oldcontext;
@@ -171,8 +122,6 @@ _pgr_withpointsvia(PG_FUNCTION_ARGS) {
                 &result_tuples,
                 &result_count);
 
-        /**********************************************************************/
-
         funcctx->max_calls = result_count;
 
         funcctx->user_fctx = result_tuples;
@@ -206,7 +155,6 @@ _pgr_withpointsvia(PG_FUNCTION_ARGS) {
             nulls[i] = false;
         }
 
-        // postgres starts counting from 1
         values[0] = Int32GetDatum((int32_t)call_cntr + 1);
         values[1] = Int32GetDatum(result_tuples[call_cntr].path_id);
         values[2] = Int32GetDatum(result_tuples[call_cntr].path_seq + 1);
@@ -218,8 +166,6 @@ _pgr_withpointsvia(PG_FUNCTION_ARGS) {
         values[8] = Float8GetDatum(result_tuples[call_cntr].agg_cost);
         values[9] = Float8GetDatum(result_tuples[call_cntr].route_agg_cost);
 
-        /**********************************************************************/
-
         tuple = heap_form_tuple(tuple_desc, values, nulls);
         result = HeapTupleGetDatum(tuple);
         SRF_RETURN_NEXT(funcctx, result);
