@@ -43,23 +43,25 @@ if ! test -d code_linter; then
 fi
 
 DIRECTORY="$1"
+INCLUDE_ORDER="-build/include_order:src/cpp_common/pgdata_getters.cpp,-build/include_order:include/cpp_common/get_data.hpp"
 
 if test -z "$DIRECTORY"; then
     echo "--------------------"
     echo "------   *.c  ------"
     echo "--------------------"
-    code_linter/cpplint/cpplint.py --extensions=c --linelength=120 --filter=-readability/casting,-whitespace/newline src/*/*.c
+    code_linter/cpplint/cpplint.py --extensions=c  --linelength=120 --filter=-readability/casting src/*/*.c
     echo "--------------------"
     echo "------ *.cpp  ------"
     echo "--------------------"
     code_linter/cpplint/cpplint.py --linelength=120 \
-        --filter=-runtime/references,-whitespace/indent_namespace \
-        src/*/*.cpp
+        --filter=-readability/nolint,-runtime/references,-whitespace/indent_namespace,"${INCLUDE_ORDER}"  \
+        --linelength=120 src/*/*.cpp
+
     echo "--------------------"
     echo "------ HEADERS  ------"
     echo "--------------------"
     code_linter/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h  --linelength=120 \
-        --filter=-runtime/references,-whitespace/indent_namespace \
+        --filter=-runtime/references,-whitespace/indent_namespace,"${INCLUDE_ORDER}" \
         include/*/*.h* \
         include/*/*/*.h*
 
@@ -70,7 +72,7 @@ else
     echo "------ IN PLACE HEADERS  ------"
     echo "--------------------"
     code_linter/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h  --linelength=120 \
-        --filter=-runtime/references \
+        --filter=-runtime/references,-whitespace/indent_namespace,"${INCLUDE_ORDER}" \
         include/*/*.h* \
         include/*/*/*.h*
 
@@ -86,8 +88,9 @@ else
         echo "------ *.cpp  ------"
         echo "--------------------"
         code_linter/cpplint/cpplint.py  --linelength=120 \
-            --filter=-runtime/references \
+            --filter=-runtime/references,-whitespace/indent_namespace,"${INCLUDE_ORDER}" \
             src/"$DIRECTORY"/*.cpp
+
         echo "--------------------"
         echo "------   C HEADER  ------"
         echo "--------------------"
@@ -99,7 +102,7 @@ else
         echo "------ C++ HEADER  ------"
         echo "--------------------"
         code_linter/cpplint/cpplint.py  --extensions=hpp,h --headers=hpp,h  --linelength=120 \
-            --filter=-runtime/references \
+            --filter=-runtime/references,-whitespace/indent_namespace,"${INCLUDE_ORDER}" \
             include/"$DIRECTORY"/*.h*
     fi
 fi
