@@ -6,14 +6,12 @@ BEGIN
   RETURN QUERY SELECT has_function(fn,    ARRAY['text']);
   RETURN QUERY SELECT function_returns(fn, ARRAY['text'], 'setof record');
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proargnames FROM pg_proc WHERE proname = %1$L$$,fn),
+  RETURN QUERY SELECT function_args_eq(fn,
     $$SELECT '{"","edge","cost"}'::TEXT[] $$
   );
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proallargtypes FROM pg_proc WHERE proname = %1$L$$, fn),
-    $$SELECT '{25,20,701}'::OID[] $$
+  RETURN QUERY SELECT function_types_eq(fn,
+    $$VALUES ('{text,int8,float8}'::TEXT[])$$
   );
 
 END;
@@ -33,35 +31,31 @@ BEGIN
 
   IF NOT min_version('3.7.0') THEN
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proargnames FROM pg_proc WHERE proname = %1$L$$,fn),
+  RETURN QUERY SELECT function_args_eq(fn,
     $$VALUES
     ('{"","","max_depth","seq","depth","start_vid","node","edge","cost","agg_cost"}'::TEXT[])
     $$
   );
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proallargtypes FROM pg_proc WHERE proname = %1$L$$, fn),
+  RETURN QUERY SELECT function_types_eq(fn,
     $$VALUES
-    ('{25,20,20,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,2277,20,20,20,20,20,20,701,701}'::OID[])
+    ('{text,int8,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,anyarray,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[])
     $$
   );
 
   ELSE
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proargnames FROM pg_proc WHERE proname = %1$L$$,fn),
+  RETURN QUERY SELECT function_args_eq(fn,
     $$VALUES
     ('{"","","max_depth","seq","depth","start_vid","pred","node","edge","cost","agg_cost"}'::TEXT[])
     $$
   );
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proallargtypes FROM pg_proc WHERE proname = %1$L$$, fn),
+  RETURN QUERY SELECT function_types_eq(fn,
     $$VALUES
-    ('{25,20,20,20,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,2277,20,20,20,20,20,20,20,701,701}'::OID[])
+    ('{text,int8,int8,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,anyarray,int8,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[])
     $$
   );
 
@@ -89,43 +83,39 @@ BEGIN
 
   IF NOT min_version('3.7.0') THEN
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proargnames FROM pg_proc WHERE proname = %1$L$$,fn),
+  RETURN QUERY SELECT function_args_eq(fn,
     $$VALUES
     ('{"","","","seq","depth","start_vid","node","edge","cost","agg_cost"}'::TEXT[])
     $$
   );
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proallargtypes FROM pg_proc WHERE proname = %1$L$$, fn),
+  RETURN QUERY SELECT function_types_eq(fn,
     $$VALUES
-    ('{25,20,701,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,2277,701,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,20,1700,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,2277,1700,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,20,701,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,2277,701,20,20,20,20,20,701,701}'::OID[])
+    ('{text,int8,float8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,anyarray,float8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,int8,numeric,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,anyarray,numeric,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,int8,float8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,anyarray,float8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[])
     $$
   );
 
   ELSE
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proargnames FROM pg_proc WHERE proname = %1$L$$,fn),
+  RETURN QUERY SELECT function_args_eq(fn,
     $$VALUES
     ('{"","","","seq","depth","start_vid","pred","node","edge","cost","agg_cost"}'::TEXT[])
     $$
   );
 
-  RETURN QUERY SELECT set_eq(
-    format($$SELECT  proallargtypes FROM pg_proc WHERE proname = %1$L$$, fn),
+  RETURN QUERY SELECT function_types_eq(fn,
     $$VALUES
-    ('{25,20,701,20,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,2277,701,20,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,20,1700,20,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,2277,1700,20,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,20,701,20,20,20,20,20,20,701,701}'::OID[]),
-    ('{25,2277,701,20,20,20,20,20,20,701,701}'::OID[])
+    ('{text,int8,float8,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,anyarray,float8,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,int8,numeric,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,anyarray,numeric,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,int8,float8,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[]),
+    ('{text,anyarray,float8,int8,int8,int8,int8,int8,int8,float8,float8}'::TEXT[])
     $$
   );
 
